@@ -6,7 +6,7 @@
 ;; Maintainer: Didier Verna <didier@xemacs.org>
 ;; Keywords:   convenience
 
-;; $Id: whitespace.el,v 1.4 2007/04/30 15:50:35 didierv Exp $
+;; $Id: whitespace.el,v 1.5 2007/05/02 08:16:16 didierv Exp $
 ;; This file is part of GNU Emacs.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
@@ -509,17 +509,19 @@ A buffer qualifies if its file name matches something in
 ;;;###autoload
 (defun whitespace-buffer (&optional quiet)
   "Find five different types of white spaces in buffer.
-These are:
-1. Leading space \(empty lines at the top of a file\).
-2. Trailing space \(empty lines at the end of a file\).
-3. Indentation space \(8 or more spaces, that should be replaced with TABS\).
-4. Spaces followed by a TAB. \(Almost always, we never want that\).
-5. Spaces or TABS at the end of a line.
 
-Check for whitespace only if this buffer really contains a non-empty file
-and:
-1. the major mode is one of the whitespace-modes, or
-2. `whitespace-buffer' was explicitly called with a prefix argument."
+These are:
+1. Leading space:  empty lines at the top of a file (should be removed).
+2. Trailing space: empty lines at the end of a file (should be removed).
+3. Indentation space: 8 or more spaces at beginning of line
+   (should be replaced with TABS).
+4. Spaces followed by a TAB (should be replaced by TABS).
+5. Spaces or TABS at the end of a line (should be removed).
+
+Check for whitespace only if buffer really contains a non-empty file, and:
+1. the file matches one item of `whitespace-files', or
+2. the major mode matches one item of `whitespace-modes', or
+3. `whitespace-buffer' was explicitly called with a prefix argument."
   (interactive)
   (let ((whitespace-error nil))
     (whitespace-check-whitespace-mode current-prefix-arg)
@@ -624,7 +626,7 @@ and:
 (defun whitespace-cleanup ()
   "Cleanup the five different kinds of whitespace problems.
 
-Use \\[describe-function] whitespace-describe to read a summary of the
+Use \`\\[describe-function] whitespace-buffer' to read a summary of the
 whitespace problems."
   (interactive)
   ;; If this buffer really contains a file, then run, else quit.
